import os

# General Settings
DNS_FILE_CHECK_INTERVAL = 7 # Number of days to evaluate until check again the dns file
CACHE_LIMIT_RECORDS = 25 # Define the max number of records that will be saved in the cache.json file
RDAP_CACHE_FILENAME = "cache.json" # Name of the file where the history is going to be saved
RDAP_DNS_FILENAME = "dns.json" # Name of the file where the hosts and tlds are going to be saved.
UNDEFINED_DATA = "Undefined" # Name of the variable to show if some data is not present.

# Files
BASE_DIR = os.path.dirname(os.path.dirname(os.path.abspath(__file__))) # Base dir of the project
CACHE_FILE_PATH = os.path.join(BASE_DIR, "rdap", "cache", "history", RDAP_CACHE_FILENAME)



class SaveCommandError(Exception):
    pass


class NotSupportedFormat(SaveCommandError):
    """
    This exception occurs when the user entersa text
    format that is not valid or is not supported by the cli.
    """

    def __init__(self, *args, **kwargs):
        super().__init__(*args, **kwargs)



from setuptools import setup, find_packages


def read_requirements() -> list:
    """simple function to read the requirements
    file and add them as a list into the
    install_requires of the CLI

    Returns:
        list: [list of libs that the CLI needs]
    """

    with open("docs/requirements.txt") as req:
        content = req.read()
        requirements = content.split("\n")

    return requirements


def get_packages() -> list:
    """simple function designed to return a list
    of packages involved in our CLI

    Returns:
        list: [package list]
    """

    root = ["rdap"]
    package_list = ["rdap.{0}".format(package) for package in find_packages(root[0])]
    return root + package_list


setup(
    name="rdap-cli",
    version="1.0.0",
    author="Alexei Popov",
    author_email="alexei.popov.cli@gmail.com",
    entry_points={
        "console_scripts": [
            "rdap=rdap.rdap:cli",
        ]
    },
    description=(
        "A simple CLI designed to offer a quick way of gathering domain"
        "data information."
    ),
    url="https://github.com/alexeipopov95/rdap-cli",
    download_url=(
        "https://github.com/alexeipopov95/rdap-cli/archive/refs/tags/1.0.0.tar.gz"
    ),
    keywords=["rdap", "cli", "whois", "registration-date", "data", "domain"],
    python_requires=">=3.6",
    install_requires=read_requirements(),
    packages=get_packages(),
    classifiers=[
        "Intended Audience :: Developers",
        "Topic :: Software Development",
        "Programming Language :: Python",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
    ],
)



import click
import pkg_resources
from rdap.common.constants import MessageColors



@click.command(name="version")
def version():
    """
    Show the project version.
    """

    version = pkg_resources.require("rdap")[0].version
    click.echo(
        click.style(
            str(version), fg=MessageColors.YELLOW, bold=True
        )
    )
    
